package com.srs.stureg.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.common.core.domain.AjaxResult;
import com.srs.stureg.domain.SrsRegPhoto;

/**
 * 新生照片Service接口
 *
 * @author srs
 * @date 2024-04-02
 */
public interface ISrsRegPhotoService extends IService<SrsRegPhoto> {

    //新生照片保存
    public AjaxResult submitOwnPhoto(SrsRegPhoto param);

    //新生照片查询
    public AjaxResult getRegPhoto(String ksh);


    /**
     * 查询新生照片
     *
     * @param id 新生照片主键
     * @return 新生照片
     */
    public SrsRegPhoto selectSrsRegPhotoById(Long id);

    /**
     * 查询新生照片列表
     *
     * @param srsRegPhoto 新生照片
     * @return 新生照片集合
     */
    List<SrsRegPhoto> selectSrsRegPhotoList(SrsRegPhoto srsRegPhoto);

    /**
     * 新增新生照片
     *
     * @param srsRegPhoto 新生照片
     * @return 结果
     */
    int insertSrsRegPhoto(SrsRegPhoto srsRegPhoto);

    /**
     * 修改新生照片
     *
     * @param srsRegPhoto 新生照片
     * @return 结果
     */
    int updateSrsRegPhoto(SrsRegPhoto srsRegPhoto);

    /**
     * 批量删除新生照片
     *
     * @param ids 需要删除的新生照片主键集合
     * @return 结果
     */
    int deleteSrsRegPhotoByIds(Long[] ids);

    /**
     * 删除新生照片信息
     *
     * @param id 新生照片主键
     * @return 结果
     */
    int deleteSrsRegPhotoById(Long id);
}
